<template>
  <basic-container>
    <avue-crud
      ref="logCrud"
      :data="tableData"
      :option="option"
      :page.sync="page"
      :table-loading="tableLoading"
      @on-load="getTableList"
      @refresh-change="handleRefresh"
      @search-change="handleSearch"
      @search-reset="handleReset"
      @size-change="sizeChange"
      @row-click="rowClickHandler"
      @current-change="currentChange"
    >
      <template slot="menuLeft" slot-scope="scope">
        <el-button icon="el-icon-download" plain size="small" type="primary" @click="exportClickHandler">导出</el-button>
      </template>
    </avue-crud>
  </basic-container>
</template>

<script>
import basicOption from "@/util/basic-option";
import {getLogListByContion,getOperatingUsers,exportLog} from "@/api/system/log/logBasic";
import func from "@/util/func";

export default {
  name: "index",
  data: function () {
    return {
      tableLoading: false,
      tableData: [],
      option: {
        ...basicOption,
        addBtn: false,
        editBtn: false,
        delBtn: false,
        calcHeight: -60,
        align: 'left',
        headerAlign: 'center',
        menu: false,
        searchMenuSpan: 6,
        searchIcon: false,
        column: [
          {
            label: '用户名',
            prop: 'truename',
            search: true,
            searchSpan: 4,
            searchLabel: '操作用户',
            type: 'select',
            dicUrl: '/api/loginBasicController/getOperatingUsers',
            sortable: true,
            width: 150
          }, {
            label: '姓名',
            prop: 'username',
            sortable: true,
            width: 150
          }, {
            label: '用户IP',
            prop: 'userIp',
            search: true,
            searchSpan: 4,
            sortable: true,
            width: 150
          }, {
            label: '模块',
            prop: 'moduleName',
            sortable: true,
            overHidden: true,
          }, {
            label: '操作',
            prop: 'type',
            sortable: true,
            width: 150
          }, {
            label: '时间',
            prop: 'date',
            type: 'date',
            search: true,
            searchOrder: 1,
            searchSpan: 8,
            searchRange: true,
            searchLabel: '查询日期',
            valueFormat: 'yyyy-MM-dd',
            width: 160
          }, {
            label: '描述',
            prop: 'result',
            overHidden: true,
            width: 380,
          },
        ]
      },
      page: {
        currentPage: 1,
        pageSize: 50,
        total: 0,
        pageSizes: [10, 30, 50, 100],
      },
      searchParams: {},
      selectList: [],

    }
  },
  watch: {
    $route(to, from) {
      this.getTableList();
    }
  },
  methods: {
    // 表格请求
    getTableList() {
      this.tableLoading = true;
      getLogListByContion(this.page.currentPage, this.page.pageSize, {'logType': this.$route.query.logType,'roleType':this.$route.query.roleType, ...this.searchParams}).then(res => {
        this.tableData = res.data.data;
        this.page.total = res.data.total;
        this.tableLoading = false;
      })
    },

    // 搜索查询
    handleSearch(params, done) {
      this.searchParams = {
        userName: params.truename,
        ipText: params.userIp,
        startDate: params.date[0],
        endDate: params.date[1]
      };

      this.getTableList();
      done();
    },

    // 重置搜索条件
    handleReset() {
      this.searchParams = {};
      this.getTableList();
    },

    // 条数
    sizeChange(val) {
      this.page.pageSize = val;
    },

    // 页码
    currentChange(val) {
      this.page.currentPage = val;
    },

    handleRefresh() {
      this.getTableList();
    },
    // 导出
    exportClickHandler() {
      const loading = this.$loading({});
      exportLog({'pageNo':1,'pageSize':-1,'logType': this.$route.query.logType,'roleType':this.$route.query.roleType, ...this.searchParams}).then(res => {
        func.downloadFileByBlobHandler(res);
        this.createdLoading = false
        this.$message.success('导出成功');
        loading.close();
      })
    },
    // 行单选
    rowClickHandler(row) {
      func.rowClickHandler(
        row,
        this.$refs.logCrud,
        this.lastIndex,
        (newIndex) => { this.lastIndex = newIndex; },
        () => { this.selectList = []; }
      );
    },
  }
}
</script>

<style scoped>

</style>
